OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Delat med dig",
    "Nothing shared with you yet" : "Inget delat med dig ännu",
    "Files and folders others share with you will show up here" : "Filer och mappar som andra delar med dig kommer visas här",
    "Shared with others" : "Delat med andra",
    "Nothing shared yet" : "Inget delat ännu",
    "Files and folders you share will show up here" : "Filer och mappar som du delar kommer visas här",
    "Shared by link" : "Delat som länk",
    "No shared links" : "Inga delade länkar",
    "Files and folders you share by link will show up here" : "Filer och mappar som du delar som länkar kommer visas här",
    "Deleted shares" : "Borttagna delningar",
    "No deleted shares" : "Inga borttagna delningar",
    "Shares you deleted will show up here" : "Borttagna delningar visas här",
    "Pending shares" : "Väntande delningar",
    "No pending shares" : "Inga väntande delningar",
    "Shares you have received but not confirmed will show up here" : "Delningar du har mottagit men inte bekräftat visas här",
    "Shares" : "Delningar",
    "No shares" : "Inga delningar",
    "Shares will show up here" : "Delningar visas här",
    "Restore" : "Återställ",
    "Restore share" : "Återställ delning",
    "Something happened. Unable to restore the share." : "Ett fel uppstod. Kan inte återställa delningen.",
    "Accept share" : "Acceptera delning",
    "Something happened. Unable to accept the share." : "Ett fel uppstod. Kan inte acceptera delningen.",
    "Reject share" : "Avvisa delning",
    "Something happened. Unable to reject the share." : "Ett fel uppstod. Kan inte avvisa delningen.",
    "Waiting…" : "Väntar...",
    "error" : "fel",
    "finished" : "klar",
    "This will stop your current uploads." : "Detta kommer att stoppa nuvarande uppladdningar.",
    "Move or copy" : "Flytta eller kopiera",
    "Download" : "Hämta",
    "Delete" : "Ta bort",
    "You can upload into this folder" : "Du kan ladda upp i denna mapp",
    "Terms of service" : "Användarvilkor",
    "No compatible server found at {remote}" : "Ingen kompatibel server hittad på {remote}",
    "Invalid server URL" : "Ogiltig serverwebbadress",
    "Failed to add the public link to your Nextcloud" : "Misslyckades skapa den offentliga delningslänken till ditt moln",
    "No expiration date set" : "Inget utgångsdatum satt",
    "Shared by" : "Delad av",
    "File shares" : "Fildelningar",
    "Downloaded via public link" : "Hämtad via offentlig länk",
    "Downloaded by {email}" : "Hämtad av {email}",
    "{file} downloaded via public link" : "{file} hämtad via offentlig länk",
    "{email} downloaded {file}" : "{email} hämtade {file}",
    "Shared with group {group}" : "Delad med grupp {group}",
    "Removed share for group {group}" : "Tog bort delning för grupp {group}",
    "{actor} shared with group {group}" : "{actor} delade med gruppen {group}",
    "{actor} removed share for group {group}" : "{actor} tog bort delningen för gruppen {group}",
    "Share for group {group} expired" : "Delning för grupp {group} har gått ut",
    "You shared {file} with group {group}" : "Du delade {file} med gruppen {group}",
    "You removed group {group} from {file}" : "Du tog bort gruppen {group} från {file}",
    "{actor} shared {file} with group {group}" : "{actor} delade {file} med gruppen {group}",
    "{actor} removed group {group} from {file}" : "{actor} tog bort gruppen {group} från {file}",
    "Share for file {file} with group {group} expired" : "Delning för fil {file} med grupp {group} har gått ut",
    "Shared as public link" : "Delades offentligt",
    "Removed public link" : "Tog bort offentlig länk",
    "Public link expired" : "Tidsgräns för offentlig länk har löpt ut",
    "{actor} shared as public link" : "{actor} delade offentligt",
    "{actor} removed public link" : "{actor} tog bort offentlig länk",
    "Public link of {actor} expired" : "Offentlig länk av {actor} har utgått",
    "You shared {file} as public link" : "Du delade {file} offentligt",
    "You removed public link for {file}" : "Du tog bort den offentliga länken för {file}",
    "Public link expired for {file}" : "Offentlig länk har utgått för {file}",
    "{actor} shared {file} as public link" : "{actor} delade {file} offentligt",
    "{actor} removed public link for {file}" : "{actor} tog bort den offentliga länken för {file}",
    "Public link of {actor} for {file} expired" : "Offentlig länk av {actor} för {file} har utgått",
    "{user} accepted the remote share" : "{user} accepterade extern delning",
    "{user} declined the remote share" : "{user} nekade extern delning",
    "You received a new remote share {file} from {user}" : "Du har fått en ny extern delning {file} från {user}",
    "{user} accepted the remote share of {file}" : "{user} accepterade extern delning av {file}",
    "{user} declined the remote share of {file}" : "{user} nekade extern delning av {file}",
    "{user} unshared {file} from you" : "{user} slutade dela {file} med dig",
    "Shared with {user}" : "Delade med {user}",
    "Removed share for {user}" : "Tog bort delningen för {user}",
    "You removed yourself" : "Du tog bort dig själv",
    "{actor} removed themselves" : "{actor} tog bort sig själva",
    "{actor} shared with {user}" : "{actor} delade med {user}",
    "{actor} removed share for {user}" : "{actor} tog bort delningen för {user}",
    "Shared by {actor}" : "Delad av {actor}",
    "{actor} removed share" : "{actor} tog bort delning",
    "Share for {user} expired" : "Delning för {user} har gått ut",
    "Share expired" : "Delning har gått ut",
    "You shared {file} with {user}" : "Du delade {file} med {user}",
    "You removed {user} from {file}" : "Du tog bort {user} från {file}",
    "You removed yourself from {file}" : "Du tog bort dig själv från {file}",
    "{actor} removed themselves from {file}" : "{actor} tog bort sig från {file}",
    "{actor} shared {file} with {user}" : "{actor} delade {file} med {user}",
    "{actor} removed {user} from {file}" : "{actor} tog bort {user} från {file}",
    "{actor} shared {file} with you" : "{actor} delade {file} med dig",
    "{actor} removed you from the share named {file}" : "{actor} tog bort dig från delningen med namn {file}",
    "Share for file {file} with {user} expired" : "Delning för fil {file} med {user} har gått ut",
    "Share for file {file} expired" : "Delning för fil {file} har gått ut",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "En fil eller mapp som delats via e-post eller offentlig länk har blivit <strong>hämtad</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mapp delades från <strong>en annan server</strong>",
    "Files" : "Filer",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mapp har <strong>delats</strong>",
    "Shared link" : "Delad länk",
    "Wrong share ID, share doesn't exist" : "Fel delnings-ID, delningen finns inte",
    "Could not delete share" : "Kunde inte ta bort delningen",
    "Please specify a file or folder path" : "Ange sökväg till filen eller mappen",
    "Could not create share" : "Kunde inte skapa delning",
    "Invalid permissions" : "Ogiltiga behörigheter",
    "Please specify a valid user" : "Ange en giltig användare",
    "Group sharing is disabled by the administrator" : "Gruppdelning är avstängt",
    "Please specify a valid group" : "Ange en giltig grupp",
    "Public link sharing is disabled by the administrator" : "Offentlig delningslänk är avstängt",
    "Public upload disabled by the administrator" : "Offentlig uppladdning är avstängt",
    "Public upload is only possible for publicly shared folders" : "Offentlig uppladdning fungerar endast i offentligt delade mappar",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Dela %s och skicka lösenordet via Nextcloud Talk går inte eftersom Nextcloud Talk är inte aktiverad",
    "Invalid date, date format must be YYYY-MM-DD" : "Ogiltigt datum, måste anges: ÅÅÅÅ-MM-DD",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Delning %1$s misslyckades för att det inte är tillåtet med delningar från typ %2$s",
    "Please specify a valid federated user ID" : "Vänligen ange ett giltigt federerat användar-id.",
    "Please specify a valid federated group ID" : "Vänligen ange ett giltigt federerat grupp-id.",
    "You cannot share to a Circle if the app is not enabled" : "Du kan inte dela till en cirkel om appen inte är aktiverad",
    "Please specify a valid circle" : "Vänligen ange en giltig cirkel",
    "Sharing %s failed because the back end does not support room shares" : "Dela %s misslyckades eftersom systemet inte stödjer rum-delningar",
    "Unknown share type" : "Ogiltig delningstyp",
    "Not a directory" : "Inte en mapp",
    "Could not lock node" : "Kunde inte låsa nod",
    "Could not lock path" : "Kunde inte låsa sökvägen",
    "Wrong or no update parameter given" : "Fel eller ingen uppdateringsparameter angiven",
    "Share must at least have READ or CREATE permissions" : "Delningen måste åtminstone ha LÄS- eller SKAPA-behörighet",
    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "\"Skicka lösenord via Nextcloud Talk\" för att dela en fil eller mapp misslyckades eftersom Nextcloud Talk inte är aktiverat.",
    "shared by %s" : "delad av %s",
    "Download all files" : "Hämta alla filer",
    "Direct link" : "Direktlänk",
    "Add to your %s" : "Lägg till i din %s",
    "Share API is disabled" : "Delning av API är inaktiverad",
    "File sharing" : "Fildelning",
    "Share will expire tomorrow" : "Delningen upphör imorgon",
    "One or more of your shares will expire tomorrow" : "En eller flera av dina delningar kommer att upphöra imorgon",
    "Your share of {node} will expire tomorrow" : "Din delning av {node} kommer upphöra imorgon",
    "You received {share} as a share by {user}" : "Du tog emot {share} som en delning från {user}",
    "You received {share} to group {group} as a share by {user}" : "Du tog emot {share} till gruppen {group} som en delning från {user}",
    "Accept" : "Acceptera",
    "Reject" : "Avvisa",
    "This application enables users to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable users can then share files and folders with other users and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other users outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "Denna applikation gör det möjligt för användare att dela filer inom Nextcloud. Om aktiverad kan administratören välja vilka grupper som kan dela filer. De tillämpliga användarna kan sedan dela filer och mappar med andra användare och grupper inom Nextcloud. Dessutom, om administratören aktiverar funktionen dela länk, kan en extern länk användas för att dela filer med andra användare utanför Nextcloud. Administratörer kan också tvinga lösenord, utgångsdatum och aktivera server till serverdelning via delningslänkar samt dela från mobila enheter.\nOm du stänger av funktionen tar du bort delade filer och mappar på servern för alla delmottagare och även på synkroniseringsklienterna och mobilapparna. Mer information finns i dokumentationen för Nextcloud.",
    "Sharing" : "Delning",
    "Accept user and group shares by default" : "Acceptera användar och grupp-delningar som standard",
    "Error while toggling options" : "Fel vid ändring av inställningar",
    "Set default folder for accepted shares" : "Sätt standardmapp för accepterade delningar",
    "Reset" : "Återställ",
    "Reset folder to system default" : "Återställ mapp till system-standard",
    "Choose a default folder for accepted shares" : "Välj en standardmapp för accepterade delningar",
    "Invalid path selected" : "Ogiltigt sökväg vald",
    "Unknown error" : "Okänt fel",
    "Allow editing" : "Tillåt redigering",
    "Read only" : "Läsbehörighet",
    "Allow upload and editing" : "Tillåt uppladdning och redigering",
    "File drop (upload only)" : "Göm fillista (endast uppladdning)",
    "Custom permissions" : "Anpassade behörigheter",
    "Read" : "Läs",
    "Upload" : "Ladda upp",
    "Edit" : "Ändra",
    "Allow creating" : "Tillåt skapa",
    "Allow deleting" : "Tillåt radera",
    "Allow resharing" : "Tillåt dela vidare",
    "Expiration date enforced" : "Förfallodatum obligatorisk",
    "Set expiration date" : "Välj utgångsdatum",
    "Enter a date" : "Ange datum",
    "Note to recipient" : "Notering till mottagare",
    "Unshare" : "Sluta dela",
    "group" : "grupp",
    "conversation" : "konversation",
    "remote" : "extern",
    "remote group" : "extern grupp",
    "guest" : "gäst",
    "Shared with the group {user} by {owner}" : "Delad med gruppen {user} av {owner}",
    "Shared with the conversation {user} by {owner}" : "Delad med konversationen {user} av {owner}",
    "Shared with {user} by {owner}" : "Delad med {user} av {owner}",
    "Added by {initiator}" : "Tillagd av {initiator}",
    "Via “{folder}”" : "Via “{folder}”",
    "Internal link" : "Intern länk",
    "Link copied" : "Länk kopierad",
    "Cannot copy, please copy the link manually" : "Kan inte kopiera, länken måste kopieras manuellt",
    "Copy to clipboard" : "Kopiera till urklipp",
    "Only works for users with access to this folder" : "Fungerar bara för användare med åtkomst till den här mappen",
    "Only works for users with access to this file" : "Fungerar bara för användare med åtkomst till den här mappen",
    "Please enter the following required information before creating the share" : "Ange följande obligatorisk information innan du skapar delningen",
    "Password protection (enforced)" : "Lösenordsskydd (obligatorisk)",
    "Password protection" : "Lösenordsskydd",
    "Enter a password" : "Ange ett lösenord",
    "Expiration date (enforced)" : "Förfallodatum (obligatorisk)",
    "Create share" : "Skapa delning",
    "Cancel" : "Avbryt",
    "Share label" : "Delningsetikett",
    "Hide download" : "Dölj hämtning",
    "Password protect" : "Lösenordsskydda",
    "Video verification" : "Video-verifiering",
    "Enter a note for the share recipient" : "Ange en notering till mottagaren",
    "Add another link" : "Lägg till en annan länk",
    "Create a new share link" : "Skapa en ny delad länk",
    "{shareWith} by {initiator}" : "{shareWith} av {initiator}",
    "Shared via link by {initiator}" : "Delad via länk av {initiator}",
    "Mail share ({label})" : "E-postdelning ({labe})",
    "Share link ({label})" : "Dela länk ({label})",
    "Share link" : "Dela länk",
    "Error, please enter proper password and/or expiration date" : "Fel, ange korrekt lösenord och/eller utgångsdatum",
    "No recommendations. Start typing." : "Inga rekommendationer. Börja skriva.",
    "Resharing is not allowed" : "Dela vidare är inte tillåtet",
    "Name or email …" : "Namn eller e-post ...",
    "Name, email, or Federated Cloud ID …" : "Namn, e-post eller federerat moln-ID ...",
    "Searching …" : "Söker ...",
    "No elements found." : "Inga element hittades.",
    "Search globally" : "Sök globalt",
    "on {server}" : "på {server}",
    "Others with access" : "Andra med åtkomst",
    "No other users with access found" : "Inga andra användare med åtkomst hittades",
    "Toggle list of others with access to this directory" : "Växla lista över andra med access till den här mappen",
    "Toggle list of others with access to this file" : "Växla lista över andra med access till den här filen",
    "Unable to fetch inherited shares" : "Kan inte hämta ärvda delningar",
    "Unable to load the shares list" : "Kunde inte läsa in delningslistan",
    "Expires {relativetime}" : "Upphör {relativetime}",
    "this share just expired." : "denna delning har just gått ut.",
    "Shared with you by {owner}" : "Delad med dig av {owner}",
    "Link to a file" : "Länka till en fil",
    "Error creating the share: {errorMessage}" : "Kunde inte skapa delningen: {errorMessage}",
    "Error creating the share" : "Kunde inte skapa delning",
    "Error updating the share: {errorMessage}" : "Kunde inte uppdatera delningen: {errorMessage}",
    "Error updating the share" : "Kunde inte uppdatera delning",
    "Shared" : "Delad",
    "Share" : "Dela",
    "Shared with" : "Delad med",
    "Shared with you and the group {group} by {owner}" : "Delad med dig och gruppen {group} av {owner}",
    "Shared with you and {circle} by {owner}" : "Delad med dig och {circle} av {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Delad med dig och konversation {conversation} av {owner}",
    "Shared with you in a conversation by {owner}" : "Delad med dig i en konversation av {owner}",
    "No entries found in this folder" : "Inga filer hittades i denna mapp",
    "Name" : "Namn",
    "Share time" : "Delningstid",
    "Expiration date" : "Utgångsdatum",
    "Sorry, this link doesn’t seem to work anymore." : "Tyvärr, denna länk verkar inte fungera längre.",
    "Reasons might be:" : "Orsaker kan vara:",
    "the item was removed" : "objektet togs bort",
    "the link expired" : "giltighet för länken har gått ut",
    "sharing is disabled" : "delning är inaktiverat",
    "For more info, please ask the person who sent this link." : "För mer information, kontakta den person som skickade den här länken.",
    "Share note" : "Dela kommentar",
    "Toggle grid view" : "Växla rutnätsvy",
    "Upload files to %s" : "Ladda upp filer till %s",
    "Note" : "Anteckning",
    "Select or drop files" : "Välj eller dra filer hit",
    "Uploading files" : "Laddar upp filer",
    "Uploaded files:" : "Uppladdade filer:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "Genom att ladda upp filer godkänner du %1$sanvändarvillkoren %2$s.",
    "Add to your Nextcloud" : "Lägg till i molnet",
    "Wrong path, file/folder doesn't exist" : "Fel sökväg, fil/mapp finns inte",
    "Cannot change permissions for public share links" : "Kan inte ändra behörigheter för publika delningslänkar",
    "Sharing sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Delning och skicka lösenordet via Nextcloud Talk går inte eftersom Nextcloud Talk är inte aktiverad"
},
"nplurals=2; plural=(n != 1);");
