OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "Kaixo %s",
    "Hello %s," : "Kaixo %s,",
    "_New notification for %s_::_%n new notifications for %s_" : ["Jakinarazpen berria %s(r)entzat","%n jakinarazpen berri %s(r)entzat"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["Jakinarazpen berri bat duzu %s(r)entzat","%n jakinarazpen berri dituzu %s(r)entzat"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "E-posta hauen maiztasuna aldatu edo desgaitu ditzakezu <a href=\"%s\">ezarpenetan</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "E-posta hauen maiztasuna aldatu edo desgaitu ditzakezu ezarpenetan: %s",
    "Admin notifications" : "Administratzailearen jakinarazpenak",
    "Notifications" : "Jakinarazpenak",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Aplikazio honek Nextclouden dagoen jakinarazpen APIaren backend eta frontend zerbitzua eskaintzen du",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "Aplikazio honek Nextclouden jakinarazpenen APIaren backend eta frontend zerbitzua eskaintzen du.\n\t\tAPIa beste aplikazio batzuk erabiltzen dute erabiltzaileei webgunean edo sinkronizazio bezeroetan hainbat gauzaren inguruko jakinarazpenak bidaltzeko. Adibidez:\n\n📬 Federatutako partekatzea: urruneko partekatze bat jaso duzu\n\n📑 Iruzkinak: beste erabiltzaile batek fitxategi baten egin duen iruzkin baten aipatu egin zaitu\n\n🚢 Eguneraketen jakinarazpena: aplikazio baten edo Nextcloud beraren eguneraketa bat dago\n\n📣 Iragarpenen zentroa: kudeatzaile batek iragarpen bat argitaratu du",
    "Dismiss all notifications" : "Baztertu jakinarazpen guztiak",
    "Requesting browser permissions to show notifications" : "Jakinarazpenak erakusteko nabigatzaileari baimena eskatzen",
    "No notifications" : "Ez dago jakinarazpenik",
    "Failed to dismiss all notifications" : "Huts egin du jakinarazpen guztiak baztertzean",
    "Failed to perform action" : "Huts egin du ekintza burutzean",
    "Dismiss" : "Baztertu",
    "seconds ago" : "segundo lehenago",
    "Failed to dismiss notification" : "Huts egin du jakinarazpena baztertzean",
    "in {path}" : "{path} -en",
    "You need to set up your email address before you can receive notification emails." : "Zure helbide elektronikoa konfiguratu behar duzu jakinarazpenak posta elektronikoz jasotzeko.",
    "Send email reminders about unhandled notifications after:" : "Bidali e-posta abisuak kudeatu gabeko jakinarazpenei buruz honen ondoren:",
    "Play sound when a new notification arrives" : "Erreproduzitu soinua jakinarazpen berri bat iristen denean",
    "Play sound when a call started (requires Nextcloud Talk)" : "Erreproduzitu soinua deia hasten denean (Nextcloud Talk behar da)",
    "Never" : "Inoiz ez",
    "1 hour" : "Ordu 1",
    "3 hours" : "3 ordu",
    "1 day" : "egun 1",
    "1 week" : "Aste 1",
    "Your settings have been updated." : "Zure ezarpenak eguneratu dira.",
    "An error occurred while updating your settings." : "Errore bat gertatu da ezarpenak eguneratzean."
},
"nplurals=2; plural=(n != 1);");
